@@ -1,26 +1,28 @@
 /*
- *  VBI proxy client
+ *  libzvbi -- VBI proxy client
  *
- *  Copyright (C) 2003-2004 Tom Zoerner
+ *  Copyright (C) 2003, 2004 Tom Zoerner
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *
- *  $Id: proxy-client.c,v 1.16 2007/11/27 18:31:06 mschimek Exp $
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-static const char rcsid[] = "$Id: proxy-client.c,v 1.16 2007/11/27 18:31:06 mschimek Exp $";
+/* $Id: proxy-client.c,v 1.18 2008/02/19 00:35:21 mschimek Exp $ */
+
+static const char rcsid[] =
+"$Id: proxy-client.c,v 1.18 2008/02/19 00:35:21 mschimek Exp $";
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -79,7 +81,6 @@ struct vbi_proxy_client
    int                     chn_scanning;
    int                     chn_prio;
    vbi_bool                has_token;
-   int                     ctrl_fd;
 
    vbi_bool                sliced_ind;
    vbi_capture_buffer      raw_buf;
@@ -1429,11 +1430,6 @@ vbi_proxy_client_stop( vbi_capture * vc )
    {
       proxy_client_stop_acq(vpc);
    }
-   if (vpc->ctrl_fd != -1)
-   {
-      close(vpc->ctrl_fd);
-      vpc->ctrl_fd = -1;
-   }
 }
 
 /* document below */
@@ -1506,9 +1502,6 @@ vbi_proxy_client_destroy( vbi_proxy_client * vpc )
       if (vpc->state != CLNT_STATE_NULL)
          proxy_client_stop_acq(vpc);
 
-      if (vpc->ctrl_fd != -1)
-         close(vpc->ctrl_fd);
-
       if (vpc->p_srv_host != NULL)
          free(vpc->p_srv_host);
 
@@ -1559,7 +1552,7 @@ vbi_proxy_client_create( const char *p_dev_name, const char *p_client_name,
       vpc->trace         = trace_level;
 
       vpc->state         = CLNT_STATE_NULL;
-      vpc->ctrl_fd       = -1;
+      vpc->io.sock_fd    = -1;
    }
    else
    {
